import { 
  			select, 
        csv, 
        scaleLinear, 
        extent, 
        scaleTime, 
  			scaleOrdinal,
        axisLeft,
  			axisBottom,
  			line,
  			curveBasis,
  			nest,
  			schemeCategory10,
  			descending
} from "d3";

import { colorLegend } from "./colorLegend";

const svg = select("svg");

const width = +svg.attr("width");
const height = +svg.attr("height"); 

const render = data => {
  const title = "A Week of Temperature Around the World";
  
  const xValue = d => d.year;
  const xAxisLabel = "Year";
  
  const yValue = d => d.temperature;
  const yAxisLabel = "Temperature";
  
  const colorValue = d => d.city;
  
  const circleRadius = 6;
  const margin = { top: 75, right: 150, bottom:70, left: 90};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height -margin.top - margin.bottom;

  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  const colorScale = scaleOrdinal(schemeCategory10);
  
  
  const xAxis = axisBottom(xScale)
      .tickSize(-innerHeight)
  		.tickPadding(15);
            
  const g = svg.append("g")
  		.attr("transform", `translate(${margin.left}, ${margin.top})`)
  
	const yAxis = axisLeft(yScale)
  		.tickSize(-innerWidth)
  		.tickPadding(10);
  
  const yAxisG = g.append("g").call(yAxis);
  yAxisG.selectAll(".domain").remove();
  
  yAxisG.append("text")
  			.attr("class", "axis-label")
  			.attr("x", -innerHeight / 2)
  			.attr("y", -50)
  			.attr("fill", "black")
  			.attr("transform", `rotate(-90)`)
  			.attr("text-anchor", "middle")
  			.text(yAxisLabel)
  
  const xAxisG = g.append("g").call(xAxis)
  	.attr("transform", `translate(0, ${innerHeight})`);
  
  
  xAxisG.select(".domain").remove();
  
	xAxisG.append("text")
  			.attr("class", "axis-label")
  			.attr("x", innerWidth/2)
  			.attr("y", 60)
  			.attr("fill", "black")
  			.text(xAxisLabel)
  
 	const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveBasis);

  const lastyValue = d => 
  	yValue(d.values[d.values.length - 1]);
  
  const nested = nest()
  	.key(colorValue)
  	.entries(data)
  	.sort((a, b) => 
      descending(lastyValue(a), lastyValue(b))
  	);
  console.log(nested);
  colorScale.domain(nested.map(d => d.key));
  
  g.selectAll(".line-path").data(nested)
  	.enter().append("path")
  	.attr("class", "line-path")
  	.attr("d", d => lineGenerator(d.values))
  	.attr("stroke", d => colorScale(d.key));
  
  g.append("text")
  	.attr("class", "title")
  	.attr("y", -15)
  	.text(title);
  
  svg.append("g")
		.attr("transform", `translate(787, 100)`)
    .call(colorLegend, {
      colorScale,
      circleRadius: 13,
  		spacing: 31,
  		textOffset: 20
	});
}


csv("https://vizhub.com/edxiao97/datasets/earthquakes-q3.csv.csv")
  .then(data => {				
		data.forEach(d => {
  		d.year = +d.year;
			d["8.0+"] = +d["8.0+"];
  });
  render(data);
});
